# Summary

This pattern demonstrates how you can integrate AWS CodeCommit and AWS CodePipeline with AWS Glue, and leverage AWS Lambda to launch jobs as soon as a developer pushes their changes to a remote AWS CodeCommit repository. This solution does the following: 

1. A Data Engineer submits a new change to an ETL repository and pushes the change to AWS CodeCommit
2. An AWS CodePipeline is invoked
3. The AWS CodePipeline triggers a Lambda function that does the following
    1. Reads the job file from the AWS CodeCommit repository by calling codecommit:GetFile and sends it to S3.
    2. Launches the AWS Glue Job with the given file.
    3. Posts the successful (or unsuccessful) result back to AWS CodePipeline, finishing the pipeline execution.
4. The AWS CodePipeline execution is finished

This solution is helpful in the situation where businesses, developers, and data engineers want to launch jobs as soon as changes are committed and pushed to the target repositories, creating a higher level of automation and making the job lifecycle less error prone.


# Sample Deployment

```
unzip codepipeline-glue-deploy-attachment.zip
cd codepipeline-glue-deploy-attachment
cdk bootstrap
cdk deploy
git init
git remote add origin <code-commit-repository-url>
git stage .
git commit -m "adds sample code"
git push --set-upstream origin main
```

# Cost

For cost information related to the sample, refer to:

1. [AWS CodeCommit pricing](https://aws.amazon.com/codecommit/pricing/)
2. [AWS CodePipeline pricing](https://aws.amazon.com/codepipeline/pricing/)
3. [AWS Glue pricing](https://aws.amazon.com/glue/pricing/)
4. [AWS Lambda Pricing](https://aws.amazon.com/lambda/pricing/)
